plugins Package
===============

:mod:`plugins` Package
----------------------

.. automodule:: rdflib.plugins
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`memory` Module
--------------------

.. automodule:: rdflib.plugins.memory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sleepycat` Module
-----------------------

.. automodule:: rdflib.plugins.sleepycat
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    rdflib.plugins.parsers
    rdflib.plugins.serializers
    rdflib.plugins.sparql
    rdflib.plugins.stores

